countries = {
    "organisation of eastern caribbean states": "Q392770",
    "organization of eastern caribbean states": "Q392770",
    "european union": "Q458",
    "hong kong":"Q8646",
    "hkg":"Q8646",
    "taiwan":"Q865",
    "twn":"Q865",
    "kosovo":"Q1246",
    "ksv":"Q1246",
    "portugal": "Q45",
    "portuguese republic": "Q45",
    "pt": "Q45",
    "🇵🇹": "Q45",
    "brazil": "Q155",
    "federative republic of brazil": "Q155",
    "brasil": "Q155",
    "república federativa do brasil": "Q155",
    "federativa república do brasil": "Q155",
    "republic federative of brasil": "Q155",
    "estados unidos del brazil": "Q155",
    "br": "Q155",
    "bra": "Q155",
    "republica federativa do brasil": "Q155",
    "federativa republica do brasil": "Q155",
    "🇧🇷": "Q155",
    "germany": "Q183",
    "frg": "Q183",
    "brd": "Q183",
    "bundesrepublik deutschland": "Q183",
    "federal republic of germany": "Q183",
    "de": "Q183",
    "deutschland": "Q183",
    "ger": "Q183",
    "bahrain": "Q398",
    "bh": "Q398",
    "kingdom of bahrain": "Q398",
    "🇧🇭": "Q398",
    "bah": "Q398",
    "israel": "Q801",
    "state of israel": "Q801",
    "israel and west bank": "Q801",
    "il": "Q801",
    "🇮🇱": "Q801",
    "holy land": "Q801",
    "the jewish state": "Q801",
    "isr": "Q801",
    "thailand": "Q869",
    "kingdom of thailand": "Q869",
    "th": "Q869",
    "siam": "Q869",
    "🇹🇭": "Q869",
    "land of smiles": "Q869",
    "tha": "Q869",
    "united arab emirates": "Q878",
    "u.a.e.": "Q878",
    "🇦🇪": "Q878",
    "uae": "Q878",
    "ae": "Q878",
    "emirates": "Q878",
    "the united arab emirates": "Q878",
    "the uae": "Q878",
    "the u.a.e.": "Q878",
    "the emirates": "Q878",
    "angola": "Q916",
    "republic of angola": "Q916",
    "ao": "Q916",
    "🇦🇴": "Q916",
    "ngola": "Q916",
    "ang": "Q916",
    "sudan": "Q1049",
    "republic of the sudan": "Q1049",
    "as-sūdān": "Q1049",
    "sd": "Q1049",
    "north sudan": "Q1049",
    "the sudan": "Q1049",
    "🇸🇩": "Q1049",
    "republic of sudan": "Q1049",
    "sud": "Q1049",
    "turkey": "Q43",
    "republic of turkey": "Q43",
    "tr": "Q43",
    "🇹🇷": "Q43",
    "tur": "Q43",
    "czech republic": "Q213",
    "czr": "Q213",
    "cz": "Q213",
    "česko": "Q213",
    "česká republika": "Q213",
    "čr": "Q213",
    "🇨🇿": "Q213",
    "cze": "Q213",
    "czechia": "Q213",
    "monaco": "Q235",
    "principality of monaco": "Q235",
    "mc": "Q235",
    "🇲🇨": "Q235",
    "mon": "Q235",
    "belize": "Q242",
    "bz": "Q242",
    "🇧🇿": "Q242",
    "algeria": "Q262",
    "people’s democratic republic of algeria": "Q262",
    "dz": "Q262",
    "🇩🇿": "Q262",
    "alg": "Q262",
    "new zealand": "Q664",
    "nz": "Q664",
    "nzl": "Q664",
    "dominion of new zealand": "Q664",
    "aotearoa": "Q664",
    "🇳🇿": "Q664",
    "venezuela": "Q717",
    "bolivarian republic of venezuela": "Q717",
    "br venezuela": "Q717",
    "ve": "Q717",
    "🇻🇪": "Q717",
    "estados unidos de venezuela": "Q717",
    "vzla": "Q717",
    "ven": "Q717",
    "central african republic": "Q929",
    "car": "Q929",
    "ködörösêse tî bêafrîka": "Q929",
    "république centrafricaine": "Q929",
    "centrafrique": "Q929",
    "cf": "Q929",
    "🇨🇫": "Q929",
    "republique centrafricaine": "Q929",
    "caf": "Q929",
    "tunisia": "Q948",
    "republic of tunisia": "Q948",
    "tūnis": "Q948",
    "tunisian republic": "Q948",
    "al-jumhūriyyah at-tūnisiyyah": "Q948",
    "tn": "Q948",
    "🇹🇳": "Q948",
    "tun": "Q948",
    "guinea bissau": "Q1007",
    "guinea-bissau": "Q1007",
    "republic of guinea-bissau": "Q1007",
    "🇬🇼": "Q1007",
    "gw": "Q1007",
    "gbs": "Q1007",
    "uganda": "Q1036",
    "republic of uganda": "Q1036",
    "ug": "Q1036",
    "🇺🇬": "Q1036",
    "uga": "Q1036",
    "ireland": "Q27",
    "éire": "Q27",
    "ie": "Q27",
    "irl": "Q27",
    "republic of ireland": "Q27",
    "hibernia": "Q27",
    "ireland, republic of": "Q27",
    "🇮🇪": "Q27",
    "eire": "Q27",
    "southern ireland": "Q27",
    "iceland": "Q189",
    "republic of iceland": "Q189",
    "is": "Q189",
    "island": "Q189",
    "🇮🇸": "Q189",
    "isl": "Q189",
    "north macedonia": "Q221",
    "republic of north macedonia": "Q221",
    "mkd": "Q221",
    "fyrom": "Q221",
    "fyr macedonia": "Q221",
    "macedonia": "Q221",
    "former yugoslav republic of macedonia": "Q221",
    "republic of macedonia": "Q221",
    "🇲🇰": "Q221",
    "mk": "Q221",
    "republic of cyprus": "Q229",
    "cy": "Q229",
    "🇨🇾": "Q229",
    "greek cypriot state": "Q229",
    "cyprus": "Q229",
    "east timor": "Q574",
    "democratic republic of timor-leste": "Q574",
    "timor-leste": "Q574",
    "tl": "Q574",
    "🇹🇱": "Q574",
    "timor leste": "Q574",
    "democratic republic of east timor": "Q574",
    "tls": "Q574",
    "fiji": "Q712",
    "republic of fiji": "Q712",
    "fj": "Q712",
    "🇫🇯": "Q712",
    "fij": "Q712",
    "republic of the fiji islands": "Q712",
    "guyana": "Q734",
    "co-operative republic of guyana": "Q734",
    "gy": "Q734",
    "republic of guyana": "Q734",
    "🇬🇾": "Q734",
    "guy": "Q734",
    "colombia": "Q739",
    "🇨🇴": "Q739",
    "república de colombia": "Q739",
    "republic of colombia": "Q739",
    "republica de colombia": "Q739",
    "col": "Q739",
    "cartagena, colombia": "Q739",
    "honduras": "Q783",
    "hn": "Q783",
    "🇭🇳": "Q783",
    "republic of honduras": "Q783",
    "honduran republic": "Q783",
    "hon": "Q783",
    "pakistan": "Q843",
    "🇵🇰": "Q843",
    "pk": "Q843",
    "islamic republic of pakistan": "Q843",
    "pak": "Q843",
    "nigeria": "Q1033",
    "federal republic of nigeria": "Q1033",
    "🇳🇬": "Q1033",
    "ng": "Q1033",
    "frn": "Q1033",
    "nga": "Q1033",
    "ngr": "Q1033",
    "naija": "Q1033",
    "lechia": "Q17050654",
    "slovakia": "Q214",
    "slovak republic": "Q214",
    "sk": "Q214",
    "🇸🇰": "Q214",
    "svk": "Q214",
    "montenegro": "Q236",
    "me": "Q236",
    "🇲🇪": "Q236",
    "mne": "Q236",
    "uzbekistan": "Q265",
    "republic of uzbekistan": "Q265",
    "uz": "Q265",
    "🇺🇿": "Q265",
    "uzb": "Q265",
    "liechtenstein": "Q347",
    "li": "Q347",
    "principality of liechtenstein": "Q347",
    "fl": "Q347",
    "🇱🇮": "Q347",
    "lie": "Q347",
    "grenada": "Q769",
    "gd": "Q769",
    "🇬🇩": "Q769",
    "grn": "Q769",
    "iraq": "Q796",
    "republic of iraq": "Q796",
    "al-‘irāq": "Q796",
    "jumhūriyyat al-‘irāq": "Q796",
    "komar-i ‘êraq": "Q796",
    "iq": "Q796",
    "🇮🇶": "Q796",
    "irq": "Q796",
    "brunei": "Q921",
    "nation of brunei, the abode of peace": "Q921",
    "bn": "Q921",
    "brunei darussalam": "Q921",
    "🇧🇳": "Q921",
    "brn": "Q921",
    "bru": "Q921",
    "zambia": "Q953",
    "republic of zambia": "Q953",
    "zm": "Q953",
    "zam": "Q953",
    "🇿🇲": "Q953",
    "botswana": "Q963",
    "republic of botswana": "Q963",
    "lefatshe la botswana": "Q963",
    "bw": "Q963",
    "🇧🇼": "Q963",
    "bot": "Q963",
    "cape verde": "Q1011",
    "republic of cape verde": "Q1011",
    "cabo verde": "Q1011",
    "cv": "Q1011",
    "cpv": "Q1011",
    "🇨🇻": "Q1011",
    "kingdom of denmark": "Q756617",
    "greenland, denmark and the faroe islands": "Q756617",
    "denmark": "Q35",
    "dk": "Q756617",
    "🇩🇰": "Q35",
    "moldova": "Q217",
    "md": "Q217",
    "republic of moldova": "Q217",
    "moldavia": "Q217",
    "republica moldova": "Q217",
    "🇲🇩": "Q217",
    "mda": "Q217",
    "barbados": "Q244",
    "bb": "Q244",
    "🇧🇧": "Q244",
    "bar": "Q244",
    "serbia": "Q403",
    "🇷🇸": "Q403",
    "republic of serbia": "Q403",
    "republika srbija": "Q403",
    "rs": "Q403",
    "srbija": "Q403",
    "srb": "Q403",
    "peru": "Q419",
    "pe": "Q419",
    "republic of peru": "Q419",
    "república del perú": "Q419",
    "🇵🇪": "Q419",
    "republica del peru": "Q419",
    "saint vincent and the grenadines": "Q757",
    "vc": "Q757",
    "st. vincent and the grenadines": "Q757",
    "st vincent and the grenadines": "Q757",
    "saint vincent": "Q757",
    "st. vincent": "Q757",
    "st vincent": "Q757",
    "🇻🇨": "Q757",
    "maldives": "Q826",
    "mv": "Q826",
    "🇲🇻": "Q826",
    "republic of maldives": "Q826",
    "mdv": "Q826",
    "bhutan": "Q917",
    "kingdom of bhutan": "Q917",
    "bt": "Q917",
    "🇧🇹": "Q917",
    "bhu": "Q917",
    "djibouti": "Q977",
    "republic of djibouti": "Q977",
    "jabuuti": "Q977",
    "gabuuti": "Q977",
    "jībūtī": "Q977",
    "dj": "Q977",
    "🇩🇯": "Q977",
    "dji": "Q977",
    "liberia": "Q1014",
    "republic of liberia": "Q1014",
    "lr": "Q1014",
    "🇱🇷": "Q1014",
    "lbr": "Q1014",
    "mauritania": "Q1025",
    "islamic republic of mauritania": "Q1025",
    "muritanya": "Q1025",
    "agawej": "Q1025",
    "gànnaar": "Q1025",
    "murutaane": "Q1025",
    "moritani": "Q1025",
    "mr": "Q1025",
    "🇲🇷": "Q1025",
    "gannaar": "Q1025",
    "mtn": "Q1025",
    "mozambique": "Q1029",
    "moçambique": "Q1029",
    "república de moçambique": "Q1029",
    "mz": "Q1029",
    "moz": "Q1029",
    "🇲🇿": "Q1029",
    "republic of mozambique": "Q1029",
    "norway": "Q20",
    "kingdom of norway": "Q20",
    "norge": "Q20",
    "norvège‏": "Q20",
    "no": "Q20",
    "nor": "Q20",
    "noreg": "Q20",
    "🇳🇴": "Q20",
    "norwegen‏": "Q20",
    "sweden": "Q34",
    "kingdom of sweden": "Q34",
    "se": "Q34",
    "swe": "Q34",
    "lithuania": "Q37",
    "republic of lithuania": "Q37",
    "lt": "Q37",
    "lietuva": "Q37",
    "🇱🇹": "Q37",
    "ltu": "Q37",
    "uruguay": "Q77",
    "república oriental del uruguay": "Q77",
    "uy": "Q77",
    "🇺🇾": "Q77",
    "uru": "Q77",
    "oriental republic of uruguay": "Q77",
    "vatican city": "Q237",
    "vatican city state": "Q237",
    "papal state": "Q237",
    "vatican": "Q237",
    "va": "Q237",
    "🇻🇦": "Q237",
    "the vatican": "Q237",
    "vat": "Q237",
    "status civitatis vaticanae": "Q237",
    "stato della città del vaticano": "Q237",
    "città del vaticano": "Q237",
    "civitas vaticana": "Q237",
    "state of vatican city": "Q237",
    "el salvador": "Q792",
    "sv": "Q792",
    "🇸🇻": "Q792",
    "republic of el salvador": "Q792",
    "esa": "Q792",
    "panama": "Q804",
    "republic of panama": "Q804",
    "pa": "Q804",
    "🇵🇦": "Q804",
    "jordan": "Q810",
    "hashemite kingdom of jordan": "Q810",
    "jo": "Q810",
    "jor": "Q810",
    "kingdom of jordan": "Q810",
    "🇯🇴": "Q810",
    "nepal": "Q837",
    "npl": "Q837",
    "federal democratic republic of nepal": "Q837",
    "nep": "Q837",
    "np": "Q837",
    "🇳🇵": "Q837",
    "saudi arabia": "Q851",
    "kingdom of saudi arabia": "Q851",
    "🇸🇦": "Q851",
    "ksa": "Q851",
    "sa": "Q851",
    "bangladesh": "Q902",
    "bd": "Q902",
    "🇧🇩": "Q902",
    "ban": "Q902",
    "tanzania": "Q924",
    "united republic of tanzania": "Q924",
    "tz": "Q924",
    "🇹🇿": "Q924",
    "united republic of tanganyika and zanzibar": "Q924",
    "benin": "Q962",
    "republic of benin": "Q962",
    "dahomey": "Q962",
    "bj": "Q962",
    "🇧🇯": "Q962",
    "ben": "Q962",
    "comoros": "Q970",
    "juzur al-qumur": "Q970",
    "juzur al-qamar": "Q970",
    "union of the comoros": "Q970",
    "udzima wa komori": "Q970",
    "union des comores": "Q970",
    "al-ittiḥād al-qumurī": "Q970",
    "km": "Q970",
    "🇰🇲": "Q970",
    "massiwa ya komori": "Q970",
    "ouvoimoja wakomori": "Q970",
    "com": "Q970",
    "equatorial guinea": "Q983",
    "republic of equatorial guinea": "Q983",
    "gq": "Q983",
    "🇬🇶": "Q983",
    "geq": "Q983",
    "ivory coast": "Q1008",
    "republic of côte d\\'ivoire": "Q1008",
    "ci": "Q1008",
    "cote d'ivoire": "Q1008",
    "cote d\\'ivoire": "Q1008",
    "🇨🇮": "Q1008",
    "côte d\\'ivoire": "Q1008",
    "republic of cote d\\'ivoire": "Q1008",
    "côte-d\\'ivoire": "Q1008",
    "cote d\\'lvoire": "Q1008",
    "cote d\\' ivoire": "Q1008",
    "côte d’ivoire": "Q1008",
    "côte d\\'ivorie": "Q1008",
    "cote d´ivoire": "Q1008",
    "cote d ivoire": "Q1008",
    "cote divoire": "Q1008",
    "cote ivoire": "Q1008",
    "cote d’ivoire": "Q1008",
    "république de côte d\\'ivoire": "Q1008",
    "republic of ivory coast": "Q1008",
    "cote-d\\'ivoire": "Q1008",
    "cote d\\'ivore": "Q1008",
    "côte d´ivoire": "Q1008",
    "côte divoire": "Q1008",
    "republic of the ivory coast": "Q1008",
    "the ivory coast": "Q1008",
    "civ": "Q1008",
    "lesotho": "Q1013",
    "kingdom of lesotho": "Q1013",
    "ls": "Q1013",
    "🇱🇸": "Q1013",
    "les": "Q1013",
    "tran dynasty": "Q3111454",
    "trần dynasty": "Q3111454",
    "canada": "Q16",
    "dominion of canada": "Q16",
    "british north america": "Q16",
    "can": "Q16",
    "ca": "Q16",
    "cdn": "Q16",
    "🇨🇦": "Q16",
    "spain": "Q29",
    "españa": "Q29",
    "kingdom of spain": "Q29",
    "es": "Q29",
    "esp": "Q29",
    "🇪🇸": "Q29",
    "switzerland": "Q39",
    "swiss confederation": "Q39",
    "sui": "Q39",
    "suisse": "Q39",
    "schweiz": "Q39",
    "svizzera": "Q39",
    "swiss": "Q39",
    "che": "Q39",
    "ch": "Q39",
    "mexico": "Q96",
    "mx": "Q96",
    "🇲🇽": "Q96",
    "united mexican states": "Q96",
    "mexican republic": "Q96",
    "mex": "Q96",
    "france": "Q142",
    "fr": "Q142",
    "république française": "Q142",
    "la france": "Q142",
    "republic of france": "Q142",
    "french republic": "Q142",
    "fra": "Q142",
    "belarus": "Q184",
    "🇧🇾": "Q184",
    "white russia": "Q184",
    "white ruthenia": "Q184",
    "republic of belarus": "Q184",
    "by": "Q184",
    "byeloruss": "Q184",
    "blr": "Q184",
    "bielorussia": "Q184",
    "belorussia": "Q184",
    "byelorussia": "Q184",
    "bosnia and herzegovina": "Q225",
    "bosnia-herzegovina": "Q225",
    "bosnia": "Q225",
    "bih": "Q225",
    "bosnia & herzegovina": "Q225",
    "b&h": "Q225",
    "🇧🇦": "Q225",
    "ba": "Q225",
    "kazakhstan": "Q232",
    "republic of kazakhstan": "Q232",
    "kz": "Q232",
    "qazaqstan": "Q232",
    "🇰🇿": "Q232",
    "kaz": "Q232",
    "jamaica": "Q766",
    "ja": "Q17",
    "commonwealth of jamaica": "Q766",
    "jm": "Q766",
    "🇯🇲": "Q766",
    "jam": "Q766",
    "the bahamas": "Q778",
    "commonwealth of the bahamas": "Q778",
    "bs": "Q778",
    "🇧🇸": "Q778",
    "bahama islands": "Q778",
    "bahamas": "Q778",
    "costa rica": "Q800",
    "republic of costa rica": "Q800",
    "🇨🇷": "Q800",
    "cr": "Q800",
    "cri": "Q800",
    "crc": "Q800",
    "syria": "Q858",
    "sy": "Q858",
    "🇸🇾": "Q858",
    "syrian arab republic": "Q858",
    "syr": "Q858",
    "ba\\'athist syria": "Q858",
    "malawi": "Q1020",
    "republic of malawi": "Q1020",
    "mw": "Q1020",
    "🇲🇼": "Q1020",
    "maw": "Q1020",
    "seychelles": "Q1042",
    "republic of seychelles": "Q1042",
    "sc": "Q1042",
    "🇸🇨": "Q1042",
    "sey": "Q1042",
    "austria": "Q40",
    "österreich": "Q40",
    "republic of austria": "Q40",
    "republik österreich": "Q40",
    "at": "Q40",
    "aut": "Q40",
    "🇦🇹": "Q40",
    "georgia": "Q230",
    "republic of georgia": "Q230",
    "ge": "Q230",
    "🇬🇪": "Q230",
    "geo": "Q230",
    "korea, north": "Q423",
    "north korea": "Q423",
    "🇰🇵": "Q423",
    "democratic people\\'s republic of korea": "Q423",
    "dprk": "Q423",
    "prk": "Q423",
    "kp": "Q423",
    "dem. rep. korea": "Q423",
    "n. korea": "Q423",
    "mongolia": "Q711",
    "mn": "Q711",
    "mongol uls": "Q711",
    "mng": "Q711",
    "🇲🇳": "Q711",
    "mgl": "Q711",
    "paraguay": "Q733",
    "republic of paraguay": "Q733",
    "py": "Q733",
    "🇵🇾": "Q733",
    "heart of south america": "Q733",
    "malaysia": "Q833",
    "my": "Q833",
    "🇲🇾": "Q833",
    "federation of malaysia": "Q833",
    "malaysia federation": "Q833",
    "mas": "Q833",
    "mys": "Q833",
    "burkina faso": "Q965",
    "bf": "Q965",
    "🇧🇫": "Q965",
    "namibia": "Q1030",
    "republic of namibia": "Q1030",
    "na": "Q1030",
    "🇳🇦": "Q1030",
    "nam": "Q1030",
    "eswatini": "Q1050",
    "umbuso weswatini": "Q1050",
    "🇸🇿": "Q1050",
    "kingdom of swaziland": "Q1050",
    "sz": "Q1050",
    "swaziland": "Q1050",
    "kingdom of eswatini": "Q1050",
    "swz": "Q1050",
    "belgium": "Q31",
    "kingdom of belgium": "Q31",
    "bel": "Q31",
    "be": "Q31",
    "🇧🇪": "Q31",
    "people\\'s republic of china": "Q148",
    "china": "Q148",
    "cn": "Q148",
    "pr china": "Q148",
    "prc": "Q148",
    "chn": "Q148",
    "communist china": "Q148",
    "🇨🇳": "Q148",
    "malta": "Q233",
    "republic of malta": "Q233",
    "mt": "Q233",
    "🇲🇹": "Q233",
    "mlt": "Q233",
    "chile": "Q298",
    "cl": "Q298",
    "república de chile": "Q298",
    "🇨🇱": "Q298",
    "republica de chile": "Q298",
    "republic of chile": "Q298",
    "chi": "Q298",
    "vanuatu": "Q686",
    "republic of vanuatu": "Q686",
    "vu": "Q686",
    "🇻🇺": "Q686",
    "vut": "Q686",
    "van": "Q686",
    "laos": "Q819",
    "lao people\\'s democratic republic": "Q819",
    "la": "Q819",
    "lao pdr": "Q819",
    "🇱🇦": "Q819",
    "lao": "Q819",
    "tajikistan": "Q863",
    "republic of tajikistan": "Q863",
    "tj": "Q863",
    "🇹🇯": "Q863",
    "tjk": "Q863",
    "mali": "Q912",
    "republic of mali": "Q912",
    "république du mali": "Q912",
    "ml": "Q912",
    "🇲🇱": "Q912",
    "republique du mali": "Q912",
    "mli": "Q912",
    "sierra leone": "Q1044",
    "republic of sierra leone": "Q1044",
    "sl": "Q1044",
    "🇸🇱": "Q1044",
    "sle": "Q1044",
    "united states of america": "Q30",
    "the united states of america": "Q30",
    "america": "Q30",
    "u.s.a.": "Q30",
    "usa": "Q30",
    "u.s.": "Q30",
    "us": "Q30",
    "the us": "Q30",
    "the usa": "Q30",
    "us of a": "Q30",
    "the united states": "Q30",
    "united states": "Q30",
    "u. s. a.": "Q30",
    "u. s.": "Q30",
    "italy": "Q38",
    "italia": "Q38",
    "italian republic": "Q38",
    "it": "Q38",
    "🇮🇹": "Q38",
    "ita": "Q38",
    "indonesia": "Q252",
    "republic of indonesia": "Q252",
    "id": "Q252",
    "🇮🇩": "Q252",
    "ina": "Q252",
    "idn": "Q252",
    "south africa": "Q258",
    "republic of south africa": "Q258",
    "rsa": "Q258",
    "za": "Q258",
    "🇿🇦": "Q258",
    "zaf": "Q258",
    "india": "Q668",
    "bharat": "Q668",
    "hindustan": "Q668",
    "bharatvarsh": "Q668",
    "in": "Q668",
    "republic of india": "Q668",
    "🇮🇳": "Q668",
    "ind": "Q668",
    "tuvalu": "Q672",
    "ellice islands": "Q672",
    "tv": "Q672",
    "🇹🇻": "Q672",
    "tuv": "Q672",
    "palau": "Q695",
    "republic of palau": "Q695",
    "belau": "Q695",
    "pelew": "Q695",
    "pw": "Q695",
    "republic of belau": "Q695",
    "🇵🇼": "Q695",
    "federated states of micronesia": "Q702",
    "micronesia": "Q702",
    "fsm": "Q702",
    "fm": "Q702",
    "fed. sts. micronesia": "Q702",
    "fed. sts. of micronesia": "Q702",
    "federated states of micronesia, fsm": "Q702",
    "🇫🇲": "Q702",
    "kiribati": "Q710",
    "republic of kiribati": "Q710",
    "🇰🇮": "Q710",
    "ki": "Q710",
    "kir": "Q710",
    "guinea": "Q1006",
    "guinea-conakry": "Q1006",
    "republic of guinea": "Q1006",
    "république de guinée": "Q1006",
    "gn": "Q1006",
    "🇬🇳": "Q1006",
    "republique de guinee": "Q1006",
    "gui": "Q1006",
    "ߖߌ߬ߣߍ߬ ߞߊ߲ߓߍ߲": "Q1006",
    "ߊߝߙߌߞߌ߬ ߕߋ߬ߟߋߓߋ ߖߡߊ߬ߣߊ ߘߏ": "Q1006",
    "mauritius": "Q1027",
    "republic of mauritius": "Q1027",
    "maurice": "Q1027",
    "moris": "Q1027",
    "mu": "Q1027",
    "🇲🇺": "Q1027",
    "mri": "Q1027",
    "ethiopia": "Q115",
    "federal democratic republic of ethiopia": "Q115",
    "et": "Q115",
    "🇪🇹": "Q115",
    "eth": "Q115",
    "united kingdom": "Q145",
    "🇬🇧": "Q145",
    "uk": "Q145",
    "united kingdom of great britain and northern ireland": "Q145",
    "u.k.": "Q145",
    "gbr": "Q145",
    "ukraine": "Q212",
    "ua": "Q212",
    "ukr": "Q212",
    "ukrainia": "Q212",
    "🇺🇦": "Q212",
    "albania": "Q222",
    "republic of albania": "Q222",
    "al": "Q222",
    "republika e shqipërisë": "Q222",
    "shqipërisë": "Q222",
    "🇦🇱": "Q222",
    "alb": "Q222",
    "papua new guinea": "Q691",
    "independent state of papua new guinea": "Q691",
    "png": "Q691",
    "pg": "Q691",
    "🇵🇬": "Q691",
    "nauru": "Q697",
    "republic of nauru": "Q697",
    "pleasant island": "Q697",
    "naoero": "Q697",
    "nr": "Q697",
    "🇳🇷": "Q697",
    "ecuador": "Q736",
    "republic of ecuador": "Q736",
    "ec": "Q736",
    "ecu": "Q736",
    "republic of the equator": "Q736",
    "the ecuadorian state": "Q736",
    "🇪🇨": "Q736",
    "bolivia": "Q750",
    "plurinational state of bolivia": "Q750",
    "bo": "Q750",
    "bol": "Q750",
    "🇧🇴": "Q750",
    "republic of bolivia": "Q750",
    "antigua and barbuda": "Q781",
    "ag": "Q781",
    "🇦🇬": "Q781",
    "ant": "Q781",
    "yemen": "Q805",
    "republic of yemen": "Q805",
    "ye": "Q805",
    "rep. yemen": "Q805",
    "🇾🇪": "Q805",
    "yem": "Q805",
    "turkmenistan": "Q874",
    "turkmenia": "Q874",
    "tm": "Q874",
    "🇹🇲": "Q874",
    "tkm": "Q874",
    "afghanistan": "Q889",
    "af": "Q889",
    "🇦🇫": "Q889",
    "islamic republic of afghanistan": "Q889",
    "afg": "Q889",
    "philippines": "Q928",
    "republic of the philippines": "Q928",
    "ph": "Q928",
    "the philippines": "Q928",
    "philippine islands": "Q928",
    "phl": "Q928",
    "rp": "Q928",
    "🇵🇭": "Q928",
    "phi": "Q928",
    "niger": "Q1032",
    "republic of niger": "Q1032",
    "republic niger": "Q1032",
    "ne": "Q1032",
    "🇳🇪": "Q1032",
    "the niger": "Q1032",
    "republic of the niger": "Q1032",
    "rwanda": "Q1037",
    "republic of rwanda": "Q1037",
    "rw": "Q1037",
    "🇷🇼": "Q1037",
    "são tomé and príncipe": "Q1039",
    "democratic republic of são tomé and príncipe": "Q1039",
    "são tomé og príncipe": "Q1039",
    "sao tome and principe": "Q1039",
    "st": "Q1039",
    "🇸🇹": "Q1039",
    "stp": "Q1039",
    "sao tome & principe": "Q1039",
    "kenya": "Q114",
    "republic of kenya": "Q114",
    "ke": "Q114",
    "ken": "Q114",
    "🇰🇪": "Q114",
    "russia": "Q159",
    "rossiya": "Q159",
    "rossija": "Q159",
    "ru": "Q159",
    "rossijskaja federatsija": "Q159",
    "russian federation": "Q159",
    "rossiyskaya federatsiya": "Q159",
    "rus": "Q159",
    "latvia": "Q211",
    "republic of latvia": "Q211",
    "latvian republic": "Q211",
    "lv": "Q211",
    "latvija": "Q211",
    "🇱🇻": "Q211",
    "lat": "Q211",
    "lva": "Q211",
    "croatia": "Q224",
    "republic of croatia": "Q224",
    "hr": "Q224",
    "hrv": "Q224",
    "🇭🇷": "Q224",
    "cro": "Q224",
    "cuba": "Q241",
    "republic of cuba": "Q241",
    "cu": "Q241",
    "🇨🇺": "Q241",
    "cub": "Q241",
    "singapore": "Q334",
    "republic of singapore": "Q334",
    "sg": "Q334",
    "🇸🇬": "Q334",
    "singapore city": "Q334",
    "sgp": "Q334",
    "lion city": "Q334",
    "garden city": "Q334",
    "australia": "Q408",
    "commonwealth of australia": "Q408",
    "au": "Q408",
    "aus": "Q408",
    "british colony of australia": "Q408",
    "🇦🇺": "Q408",
    "straya": "Q408",
    "guatemala": "Q774",
    "gt": "Q774",
    "🇬🇹": "Q774",
    "republic of guatemala": "Q774",
    "gua": "Q774",
    "dominican republic": "Q786",
    "república dominicana": "Q786",
    "🇩🇴": "Q786",
    "rd": "Q786",
    "dr": "Q786",
    "republica dominicana": "Q786",
    "kyrgyzstan": "Q813",
    "kyrgyz republic": "Q813",
    "kg": "Q813",
    "kirgizia": "Q813",
    "🇰🇬": "Q813",
    "kgz": "Q813",
    "lebanon": "Q822",
    "lebanese republic": "Q822",
    "lb": "Q822",
    "republic of lebanon": "Q822",
    "🇱🇧": "Q822",
    "lbn": "Q822",
    "sri lanka": "Q854",
    "democratic socialist republic of sri lanka": "Q854",
    "ceylon": "Q854",
    "taprobane": "Q854",
    "serendib": "Q854",
    "ceylan": "Q854",
    "🇱🇰": "Q854",
    "lk": "Q854",
    "lanka, sri": "Q854",
    "sri": "Q854",
    "lke": "Q854",
    "ce": "Q854",
    "srilanka": "Q854",
    "vietnam": "Q881",
    "viet nam": "Q881",
    "socialist republic of vietnam": "Q881",
    "🇻🇳": "Q881",
    "vn": "Q881",
    "vie": "Q881",
    "togo": "Q945",
    "togolese republic": "Q945",
    "république togolaise": "Q945",
    "tg": "Q945",
    "🇹🇬": "Q945",
    "republique togolaise": "Q945",
    "tog": "Q945",
    "the gambia": "Q1005",
    "gm": "Q1005",
    "islamic republic of the gambia": "Q1005",
    "🇬🇲": "Q1005",
    "republic of the gambia": "Q1005",
    "gam": "Q1005",
    "gambia": "Q1005",
    "senegal": "Q1041",
    "republic of senegal": "Q1041",
    "république du sénégal": "Q1041",
    "sn": "Q1041",
    "sénégal": "Q1041",
    "🇸🇳": "Q1041",
    "republique du senegal": "Q1041",
    "sen": "Q1041",
    "tây sơn dynasty": "Q1034173",
    "finland": "Q33",
    "republic of finland": "Q33",
    "finlande": "Q33",
    "finlandia": "Q33",
    "finnland": "Q33",
    "finnia": "Q33",
    "land of thousand lakes": "Q33",
    "fi": "Q33",
    "suomi": "Q33",
    "suomen tasavalta": "Q33",
    "republiken finland": "Q33",
    "🇫🇮": "Q33",
    "fin": "Q33",
    "romania": "Q218",
    "roumania": "Q218",
    "rumania": "Q218",
    "românia": "Q218",
    "ro": "Q218",
    "🇷🇴": "Q218",
    "andorra": "Q228",
    "principality of andorra": "Q228",
    "principality of the valleys of andorra": "Q228",
    "ad": "Q228",
    "🇦🇩": "Q228",
    "and": "Q228",
    "argentina": "Q414",
    "ar": "Q414",
    "🇦🇷": "Q414",
    "argentine republic": "Q414",
    "arg": "Q414",
    "cambodia": "Q424",
    "kingdom of cambodia": "Q424",
    "kh": "Q424",
    "🇰🇭": "Q424",
    "kampuchea": "Q424",
    "camboya": "Q424",
    "campuchia": "Q424",
    "kamboja": "Q424",
    "kambodzha": "Q424",
    "samoa": "Q683",
    "western samoa": "Q683",
    "independent state of samoa": "Q683",
    "ws": "Q683",
    "🇼🇸": "Q683",
    "solomon islands": "Q685",
    "sb": "Q685",
    "🇸🇧": "Q685",
    "sol": "Q685",
    "saint kitts and nevis": "Q763",
    "saint christopher and nevis": "Q763",
    "federation of saint kitts and nevis": "Q763",
    "kn": "Q763",
    "st. kitts and nevis": "Q763",
    "st kitts and nevis": "Q763",
    "🇰🇳": "Q763",
    "st. kitts & nevis": "Q763",
    "kitts & nevis": "Q763",
    "cameroon": "Q1009",
    "republic of cameroon": "Q1009",
    "cm": "Q1009",
    "🇨🇲": "Q1009",
    "cmr": "Q1009",
    "cam": "Q1009",
    "somalia": "Q1045",
    "federal republic of somalia": "Q1045",
    "aṣ-ṣūmāl": "Q1045",
    "soomaaliya": "Q1045",
    "so": "Q1045",
    "🇸🇴": "Q1045",
    "som": "Q1045",
    "japan": "Q17",
    "state of japan": "Q17",
    "land of the rising sun": "Q17",
    "nihon": "Q17",
    "nippon": "Q17",
    "jp": "Q17",
    "nippon-koku": "Q17",
    "nihon-koku": "Q17",
    "jpn": "Q17",
    "jap": "Q17",
    "danmark": "Q35",
    "dnk": "Q756617",
    "dek": "Q35",
    "denmark proper": "Q35",
    "metropolitan denmark": "Q35",
    "den": "Q35",
    "tan": "Q35",
    "greece": "Q41",
    "hellenic republic": "Q41",
    "hellas": "Q41",
    "gr": "Q41",
    "🇬🇷": "Q41",
    "greek republic": "Q41",
    "gre": "Q41",
    "estonia": "Q191",
    "republic of estonia": "Q191",
    "estland": "Q191",
    "eesti": "Q191",
    "ee": "Q191",
    "est": "Q191",
    "🇪🇪": "Q191",
    "slovenia": "Q215",
    "slovenija": "Q215",
    "republika slovenija": "Q215",
    "si": "Q215",
    "🇸🇮": "Q215",
    "svn": "Q215",
    "slo": "Q215",
    "republic of slovenia": "Q215",
    "san marino": "Q238",
    "sm": "Q238",
    "🇸🇲": "Q238",
    "most serene republic of san marino": "Q238",
    "smr": "Q238",
    "armenia": "Q399",
    "republic of armenia": "Q399",
    "🇦🇲": "Q399",
    "arm": "Q399",
    "tonga": "Q678",
    "🇹🇴": "Q678",
    "to": "Q678",
    "kingdom of tonga": "Q678",
    "tga": "Q678",
    "trinidad and tobago": "Q754",
    "republic of trinidad and tobago": "Q754",
    "tt": "Q754",
    "🇹🇹": "Q754",
    "tto": "Q754",
    "saint lucia": "Q760",
    "lc": "Q760",
    "st. lucia": "Q760",
    "st lucia": "Q760",
    "🇱🇨": "Q760",
    "nicaragua": "Q811",
    "ni": "Q811",
    "🇳🇮": "Q811",
    "republic of nicaragua": "Q811",
    "nic": "Q811",
    "nca": "Q811",
    "kuwait": "Q817",
    "🇰🇼": "Q817",
    "state of kuwait": "Q817",
    "dawlat al-kuwait": "Q817",
    "kw": "Q817",
    "kuw": "Q817",
    "myanmar": "Q836",
    "burma": "Q836",
    "republic of the union of myanmar": "Q836",
    "union of burma": "Q836",
    "mm": "Q836",
    "🇲🇲": "Q836",
    "bur": "Q836",
    "mya": "Q836",
    "oman": "Q842",
    "om": "Q842",
    "🇴🇲": "Q842",
    "sultanate of oman": "Q842",
    "zimbabwe": "Q954",
    "republic of zimbabwe": "Q954",
    "southern rhodesia": "Q954",
    "rhodesia": "Q954",
    "zimbabwe rhodesia": "Q954",
    "🇿🇼": "Q954",
    "zw": "Q954",
    "zim": "Q954",
    "burundi": "Q967",
    "republic of burundi": "Q967",
    "bi": "Q967",
    "🇧🇮": "Q967",
    "republika y\\'uburundi": "Q967",
    "gouvernement du burundi": "Q967",
    "bdi": "Q967",
    "democratic republic of the congo": "Q974",
    "drc": "Q974",
    "congo democratic republic":  "Q974",
    "dr congo": "Q974",
    "congo-kinshasa": "Q974",
    "zaire": "Q974",
    "congo": "Q974",
    "democratic republic of congo": "Q974",
    "cd": "Q974",
    "dem. republic of the congo": "Q974",
    "dem. republic of congo": "Q974",
    "dem. rep. congo": "Q974",
    "🇨🇩": "Q974",
    "congo (kinshasa)": "Q974",
    "cod": "Q974",
    "gabon": "Q1000",
    "gabonese republic": "Q1000",
    "république gabonaise": "Q1000",
    "ga": "Q1000",
    "🇬🇦": "Q1000",
    "republique gabonaise": "Q1000",
    "gab": "Q1000",
    "libya": "Q1016",
    "state of libya": "Q1016",
    "ly": "Q1016",
    "🇱🇾": "Q1016",
    "lba": "Q1016",
    "ly dynasty": "Q878309",
    "lý dynasty": "Q878309",
    "hungary": "Q28",
    "hu": "Q28",
    "🇭🇺": "Q28",
    "hun": "Q28",
    "poland": "Q36",
    "pol": "Q36",
    "republic of poland": "Q36",
    "pl": "Q36",
    "polska": "Q36",
    "🇵🇱": "Q36",
    "azerbaijan": "Q227",
    "republic of azerbaijan": "Q227",
    "az": "Q227",
    "🇦🇿": "Q227",
    "aze": "Q227",
    "chad": "Q657",
    "republic of chad": "Q657",
    "république du tchad": "Q657",
    "جمهورية تشاد": "Q657",
    "ǧumhūriyyat tšād": "Q657",
    "tchad": "Q657",
    "td": "Q657",
    "🇹🇩": "Q657",
    "republique du tchad": "Q657",
    "cha": "Q657",
    "gum": "Q657",
    "marshall islands": "Q709",
    "republic of the marshall islands": "Q709",
    "aolepān aorōkin m̧ajeļ": "Q709",
    "mh": "Q709",
    "🇲🇭": "Q709",
    "mhl": "Q709",
    "dominica": "Q784",
    "commonwealth of dominica": "Q784",
    "the commonwealth of dominica": "Q784",
    "🇩🇲": "Q784",
    "dm": "Q784",
    "dom": "Q786",
    "dma": "Q784",
    "kingdom of the netherlands": "Q29999",
    "the netherlands": "Q29999",
    "netherlands": "Q29999",
    "nl": "Q29999",
    "🇳🇱": "Q29999",
    "egypt": "Q79",
    "republic of egypt": "Q79",
    "eg": "Q79",
    "egy": "Q79",
    "🇪🇬": "Q79",
    "arab republic of egypt": "Q79",
    "arab rep. egypt": "Q79",
    "rep. egypt": "Q79",
    "luxembourg": "Q32",
    "luxemburg": "Q32",
    "grand duchy of luxembourg": "Q32",
    "lu": "Q32",
    "🇱🇺": "Q32",
    "lux": "Q32",
    "ghana": "Q117",
    "republic of ghana": "Q117",
    "🇬🇭": "Q117",
    "gh": "Q117",
    "gha": "Q117",
    "bulgaria": "Q219",
    "republic of bulgaria": "Q219",
    "bg": "Q219",
    "🇧🇬": "Q219",
    "bul": "Q219",
    "bgr": "Q219",
    "suriname": "Q730",
    "surinam": "Q730",
    "republic of suriname": "Q730",
    "republic of surinam": "Q730",
    "dutch guiana": "Q730",
    "sr": "Q730",
    "🇸🇷": "Q730",
    "sur": "Q730",
    "haiti": "Q790",
    "republic of haiti": "Q790",
    "ht": "Q790",
    "hayti": "Q790",
    "république d\\'haïti": "Q790",
    "haitian republic": "Q790",
    "ayiti": "Q790",
    "🇭🇹": "Q790",
    "hai": "Q790",
    "iran": "Q794",
    "islamic republic of iran": "Q794",
    "persia": "Q794",
    "ir": "Q794",
    "islamic rep. iran": "Q794",
    "🇮🇷": "Q794",
    "republic of iran": "Q794",
    "qatar": "Q846",
    "qat": "Q846",
    "qa": "Q846",
    "state of qatar": "Q846",
    "🇶🇦": "Q846",
    "korea, south": "Q884",
    "south korea": "Q884",
    "republic of korea": "Q884",
    "rok": "Q884",
    "daehan minguk": "Q884",
    "the republic of great han": "Q884",
    "republic of great han": "Q884",
    "kr": "Q884",
    "rep. korea": "Q884",
    "s. korea": "Q884",
    "korea republic": "Q884",
    "republic of south korea": "Q884",
    "🇰🇷": "Q884",
    "kor": "Q884",
    "south sudan": "Q958",
    "republic of south sudan": "Q958",
    "southern sudan": "Q958",
    "ss": "Q958",
    "🇸🇸": "Q958",
    "ssd": "Q958",
    "republic of the congo": "Q971",
    "congo-brazzaville": "Q971",
    "congo republic": "Q971",
    "république du congo": "Q971",
    "republic of congo": "Q971",
    "cg": "Q971",
    "rep. congo": "Q971",
    "🇨🇬": "Q971",
    "republique du congo": "Q971",
    "congo (brazzaville)": "Q971",
    "cgo": "Q971",
    "eritrea": "Q986",
    "state of eritrea": "Q986",
    "ertrā": "Q986",
    "iritriyā": "Q986",
    "er": "Q986",
    "🇪🇷": "Q986",
    "eri": "Q986",
    "iri": "Q986",
    "madagascar": "Q1019",
    "mg": "Q1019",
    "🇲🇬": "Q1019",
    "republic of madagascar": "Q1019",
    "mad": "Q1019",
    "morocco": "Q1028",
    "kingdom of morocco": "Q1028",
    "arab maghreb": "Q1028",
    "marocco": "Q1028",
    "al-maġrib": "Q1028",
    "lmaġrib": "Q1028",
    "maroc": "Q1028",
    "ma": "Q1028",
    "🇲🇦": "Q1028",
    "mar": "Q1028",
    "124": "Q16",
    "392": "Q17",
    "578": "Q20",
    "372": "Q27",
    "348": "Q28",
    "724": "Q29",
    "840": "Q30",
    "056": "Q31",
    "442": "Q32",
    "246": "Q33",
    "752": "Q34",
    "208": "Q35",
    "616": "Q36",
    "440": "Q37",
    "380": "Q38",
    "756": "Q39",
    "040": "Q40",
    "grc": "Q41",
    "300": "Q41",
    "792": "Q43",
    "prt": "Q45",
    "620": "Q45",
    "ury": "Q77",
    "858": "Q77",
    "818": "Q79",
    "484": "Q96",
    "404": "Q114",
    "231": "Q115",
    "288": "Q117",
    "250": "Q142",
    "gb": "Q145",
    "826": "Q145",
    "156": "Q148",
    "076": "Q155",
    "643": "Q159",
    "deu": "Q183",
    "276": "Q183",
    "112": "Q184",
    "352": "Q189",
    "233": "Q191",
    "428": "Q211",
    "804": "Q212",
    "203": "Q213",
    "703": "Q214",
    "705": "Q215",
    "498": "Q217",
    "rou": "Q218",
    "642": "Q218",
    "100": "Q219",
    "807": "Q221",
    "008": "Q222",
    "191": "Q224",
    "070": "Q225",
    "031": "Q227",
    "020": "Q228",
    "cyp": "Q229",
    "196": "Q229",
    "268": "Q230",
    "398": "Q232",
    "470": "Q233",
    "mco": "Q235",
    "492": "Q235",
    "499": "Q236",
    "336": "Q237",
    "674": "Q238",
    "192": "Q241",
    "blz": "Q242",
    "084": "Q242",
    "brb": "Q244",
    "052": "Q244",
    "360": "Q252",
    "710": "Q258",
    "dza": "Q262",
    "012": "Q262",
    "860": "Q265",
    "chl": "Q298",
    "152": "Q298",
    "702": "Q334",
    "438": "Q347",
    "bhr": "Q398",
    "048": "Q398",
    "am": "Q399",
    "051": "Q399",
    "688": "Q403",
    "036": "Q408",
    "032": "Q414",
    "per": "Q419",
    "604": "Q419",
    "408": "Q423",
    "khm": "Q424",
    "116": "Q424",
    "626": "Q574",
    "tcd": "Q657",
    "148": "Q657",
    "554": "Q664",
    "356": "Q668",
    "798": "Q672",
    "ton": "Q678",
    "776": "Q678",
    "wsm": "Q683",
    "882": "Q683",
    "slb": "Q685",
    "090": "Q685",
    "548": "Q686",
    "598": "Q691",
    "plw": "Q695",
    "585": "Q695",
    "nru": "Q697",
    "520": "Q697",
    "583": "Q702",
    "584": "Q709",
    "296": "Q710",
    "496": "Q711",
    "fji": "Q712",
    "242": "Q712",
    "862": "Q717",
    "740": "Q730",
    "pry": "Q733",
    "600": "Q733",
    "328": "Q734",
    "218": "Q736",
    "co": "Q739",
    "170": "Q739",
    "068": "Q750",
    "780": "Q754",
    "vct": "Q757",
    "670": "Q757",
    "lca": "Q760",
    "662": "Q760",
    "kna": "Q763",
    "659": "Q763",
    "388": "Q766",
    "grd": "Q769",
    "308": "Q769",
    "gtm": "Q774",
    "320": "Q774",
    "bhs": "Q778",
    "044": "Q778",
    "atg": "Q781",
    "028": "Q781",
    "hnd": "Q783",
    "340": "Q783",
    "212": "Q784",
    "do": "Q786",
    "214": "Q786",
    "hti": "Q790",
    "332": "Q790",
    "slv": "Q792",
    "222": "Q792",
    "irn": "Q794",
    "364": "Q794",
    "368": "Q796",
    "188": "Q800",
    "376": "Q801",
    "pan": "Q804",
    "591": "Q804",
    "887": "Q805",
    "400": "Q810",
    "558": "Q811",
    "417": "Q813",
    "kwt": "Q817",
    "414": "Q817",
    "418": "Q819",
    "422": "Q822",
    "462": "Q826",
    "458": "Q833",
    "mmr": "Q836",
    "104": "Q836",
    "524": "Q837",
    "omn": "Q842",
    "512": "Q842",
    "586": "Q843",
    "qat": "Q846",
    "634": "Q846",
    "sau": "Q851",
    "682": "Q851",
    "lka": "Q854",
    "144": "Q854",
    "760": "Q858",
    "762": "Q863",
    "764": "Q869",
    "795": "Q874",
    "are": "Q878",
    "784": "Q878",
    "vnm": "Q881",
    "704": "Q881",
    "410": "Q884",
    "004": "Q889",
    "bgd": "Q902",
    "050": "Q902",
    "466": "Q912",
    "ago": "Q916",
    "024": "Q916",
    "btn": "Q917",
    "064": "Q917",
    "096": "Q921",
    "tza": "Q924",
    "834": "Q924",
    "608": "Q928",
    "140": "Q929",
    "tgo": "Q945",
    "768": "Q945",
    "788": "Q948",
    "zmb": "Q953",
    "894": "Q953",
    "zwe": "Q954",
    "716": "Q954",
    "728": "Q958",
    "204": "Q962",
    "bwa": "Q963",
    "072": "Q963",
    "bfa": "Q965",
    "854": "Q965",
    "108": "Q967",
    "174": "Q970",
    "cog": "Q971",
    "178": "Q971",
    "180": "Q974",
    "262": "Q977",
    "gnq": "Q983",
    "226": "Q983",
    "232": "Q986",
    "266": "Q1000",
    "gmb": "Q1005",
    "270": "Q1005",
    "gin": "Q1006",
    "324": "Q1006",
    "gnb": "Q1007",
    "624": "Q1007",
    "384": "Q1008",
    "120": "Q1009",
    "132": "Q1011",
    "lso": "Q1013",
    "426": "Q1013",
    "430": "Q1014",
    "lby": "Q1016",
    "434": "Q1016",
    "mdg": "Q1019",
    "450": "Q1019",
    "mwi": "Q1020",
    "454": "Q1020",
    "mrt": "Q1025",
    "478": "Q1025",
    "mus": "Q1027",
    "480": "Q1027",
    "504": "Q1028",
    "508": "Q1029",
    "516": "Q1030",
    "ner": "Q1032",
    "562": "Q1032",
    "566": "Q1033",
    "800": "Q1036",
    "rwa": "Q1037",
    "646": "Q1037",
    "678": "Q1039",
    "686": "Q1041",
    "syc": "Q1042",
    "690": "Q1042",
    "694": "Q1044",
    "706": "Q1045",
    "sdn": "Q1049",
    "729": "Q1049",
    "748": "Q1050",
    "nld": "Q29999",
    "528": "Q29999"
  }
